API Reference
=============

This page presents the complete API documentation.

.. autosummary::
    :toctree: generated

    dir_content_diff
    dir_content_diff.base_comparators
    dir_content_diff.util
    dir_content_diff.pandas
    dir_content_diff.pytest_plugin
